@@ -1,8 +1,8 @@
 import file from "file";
-import path from "path";
 import deref from "json-schema-deref-sync";
-import {JSONInclude} from "../json_include";
+import path from "path";
 
+import { JSONInclude } from "../json_include";
 
 /**
  * Resolves `include` and `$ref` statements.
@@ -12,9 +12,9 @@ export function parseIncludeReferenceStatements(filePath) {
     const jsonResolver = new JSONInclude();
     const parsed = jsonResolver.parseIncludeStatements(filePath);
     const dirPath = path.dirname(filePath);
-    let dereferenced = deref(parsed, {baseFolder: dirPath});
+    let dereferenced = deref(parsed, { baseFolder: dirPath });
     // handle circular references and use non-dereferenced source
-    if ((dereferenced instanceof Error) && (dereferenced.message === "Circular self reference")) {
+    if (dereferenced instanceof Error && dereferenced.message === "Circular self reference") {
         dereferenced = parsed;
     }
     return dereferenced;
@@ -27,7 +27,7 @@ export function parseIncludeReferenceStatements(filePath) {
 export function parseIncludeReferenceStatementsByDir(dirPath) {
     const data = [];
     file.walkSync(dirPath, (dirPath_, dirs_, files_) => {
-        files_.forEach(file_ => {
+        files_.forEach((file_) => {
             const filePath = path.join(dirPath_, file_);
             data.push(parseIncludeReferenceStatements(filePath));
         });
